==> haskell-th-utilities-0.2.5.2-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-utilities.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 th-utilities
version:              0.2.5.2
visibility:           public
id:                   th-utilities-0.2.5.2-LLG6ZUsmMeqBMMLPeM8UOg
key:                  th-utilities-0.2.5.2-LLG6ZUsmMeqBMMLPeM8UOg
license:              MIT
copyright:            2016 FP Complete
maintainer:           Michael Sloan <mgsloan@gmail.com>
homepage:             https://github.com/fpco/th-utilities#readme
synopsis:
    Collection of useful functions for use with Template Haskell

category:             Template Haskell
abi:                  6d219d223809fe52e620889470949afb
exposed:              True
exposed-modules:
    TH.Derive TH.Derive.Storable TH.FixQ TH.ReifySimple
    TH.RelativePaths TH.Utilities

hidden-modules:       TH.Derive.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/th-utilities-0.2.5.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/th-utilities-0.2.5.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/th-utilities-0.2.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-utilities
hs-libraries:         HSth-utilities-0.2.5.2-LLG6ZUsmMeqBMMLPeM8UOg
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    directory-1.3.7.1 filepath-1.4.2.2
    primitive-0.8.0.0-AkaLl3oBd0zGZjVVLiSfZ
    syb-0.7.2.4-DRmRuYXhogH1Si3eC7RXHC template-haskell-2.19.0.0
    text-2.0.2 th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy
    th-orphans-0.13.15-7BLEhIg54qyGs2R7vtwLU3

haddock-interfaces:
    /usr/share/doc/haskell-th-utilities/html/th-utilities.haddock

haddock-html:         /usr/share/doc/haskell-th-utilities/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-utilities-0.2.5.2-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-utilities.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 th-utilities
version:              0.2.5.2
visibility:           public
id:                   th-utilities-0.2.5.2-872EGyMSfqYFEyQ62ac2g8
key:                  th-utilities-0.2.5.2-872EGyMSfqYFEyQ62ac2g8
license:              MIT
copyright:            2016 FP Complete
maintainer:           Michael Sloan <mgsloan@gmail.com>
homepage:             https://github.com/fpco/th-utilities#readme
synopsis:
    Collection of useful functions for use with Template Haskell

category:             Template Haskell
abi:                  68c039d758f74f62beb007ad8bb0e237
exposed:              True
exposed-modules:
    TH.Derive TH.Derive.Storable TH.FixQ TH.ReifySimple
    TH.RelativePaths TH.Utilities

hidden-modules:       TH.Derive.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/th-utilities-0.2.5.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/th-utilities-0.2.5.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/th-utilities-0.2.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-utilities
hs-libraries:         HSth-utilities-0.2.5.2-872EGyMSfqYFEyQ62ac2g8
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    directory-1.3.7.1 filepath-1.4.2.2
    primitive-0.8.0.0-AkaLl3oBd0zGZjVVLiSfZ
    syb-0.7.2.4-DRmRuYXhogH1Si3eC7RXHC template-haskell-2.19.0.0
    text-2.0.2 th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy
    th-orphans-0.13.15-4NO9tkp0eCTEMnnxLCkX2p

haddock-interfaces:
    /usr/share/doc/haskell-th-utilities/html/th-utilities.haddock

haddock-html:         /usr/share/doc/haskell-th-utilities/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
